$TITLE ('COS DCE Boot-mode Patchable Constants, version 01.00')
$PAGELENGTH(42)
;*****************************************************************************
; File -- patchcst.a51
; Purpose -- COS DCE 8051 boot code, patchable constants.  In this file are
;            defined and allocated various parameters which control operation
;            of the boot-mode software.  These parameters are copied from CODE
;            space, where they are allocated, to XDATA upon startup so that
;            they may be changed through simple data uploads.
;
;            ------------------------   --------------------------------------
; Authors -- Original code by ...       Adapted for Boot-mode by ...
;            ------------------------   --------------------------------------
;            Mr. Daniel B. Blackman     William I. Clement, Ph.D., President
;            P.O. Box 20627             Clement Engineering, Inc.
;            Oakland, CA  94620         1261 Dogwood Road
;            (510) 910-9047             Arnold, MD  21012-2220
;                                       (410) 518-6591
;            ------------------------   --------------------------------------
;
; Change History --
; 24Aug00   Code version v17088 accepted by WIC from DBB
; 15Sep00   WIC, Boot code version 01.00 delivered.
;*****************************************************************************

$SET (PATCHCST=1)
$INCLUDE(common.inc)

   CSEG  at  PATCHCST_SEG   ; This is where we place the patchable constants
                            ; in CODE space.  They will be copied from here
                            ; to a DIFFERENT address in XDATA by subroutine
                            ; 'COPY_PATCHABLE'.  The table 'patch_table'
                            ; (below) gives the starting address, destination
                            ; address, and number of bytes to copy to
                            ; facilitate this task.

patchable_CSEG:             ; beginning label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

;*****************************************************************************
;                          Flight Software version
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
cLFDSWVER:
   DW   0100h               ; Version number 01.00
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'HSTERR_TABLE' provides conversion from diagnostic to HST error.
; Entries are pointers to HST error parameter.  Null pointers are for
; diagnostics which are NOT HST errors.
; NOTE:  'cHSTERR_TABLE' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'HSTERR_TABLE' reflects that XDATA location.  It is the XDATA location
;    ('HSTERR_TABLE') which is referenced in the software.
;*****************************************************************************
null_ptr   equ   0

FILL_TO_BOUNDARY   16, 0FFh
cHSTERR_TABLE:
   DW   null_ptr,     PARAM2,     PARAM3,     PARAM2     ; 00..03
   DW    SERIALN,    SERIALN,    SERIALN,   null_ptr     ; 04..07
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 08..0B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 0C..0F

   DW   null_ptr,       RS17,   null_ptr,   null_ptr     ; 10..13
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 14..17
   DW    mLFMLWR,    mLFMUPR,    mLFMCRC,   mLFCTIME     ; 18..1B
   DW   mLFCTIME,   null_ptr,   null_ptr,   mLFCTIME     ; 1C..1F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 20..23
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 24..27
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 28..2B
   DW   null_ptr,   null_ptr,   null_ptr,       RS17     ; 2C..2F

$if 0
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 30..33
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 34..37
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 38..3B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 3C..3F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 40..43
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 44..47
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 48..4B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 4C..4F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 50..53
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 54..57
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 58..5B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 5C..5F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 60..63
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 64..67
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 68..6B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 6C..6F

   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 70..73
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 74..77
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 78..7B
   DW   null_ptr,   null_ptr,   null_ptr,   null_ptr     ; 7C..7F
$endif
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'COS_BOOT_TBL' is a table of function addresses.  When a command opcode is
; received, the address of the corresponding routine is looked up in this
; table and then a jump is performed.
; NOTE:  'cCOS_BOOT_TBL' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'COS_BOOT_TBL' reflects that XDATA location.  It is the XDATA location
;    ('COS_BOOT_TBL') which is referenced in the software.
; NOTE:  Routine 'CMD_ILLEGAL' handles commands that are illegal for both Boot
;    and Operate modes.  Routine 'CMD_OPERATE' handles those which are legal
;    for Operage mode but illegal for Boot mode.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
cCOS_BOOT_TBL:
   DW   DCE_LFDNOOP   ; 00H *No Operation
   DW   DCE_LFDMADDR  ; 01H  index,addr,bank
   DW   DCE_LFDCRC    ; 02H  Inserts specific CRC region in background
   DW   DCE_LFDCOPY   ; 03H  Copy memory-to-memory on command
   DW   CMD_ILLEGAL   ; 04H  No Operation, undefined command
   DW   CMD_OPERATE   ; 05H *SET BITS FOR TDC-A START (BEGIN) CFD WALK ADJ
   DW   CMD_ILLEGAL   ; 06H *SET BITS FOR TDC-B START (BEGIN) CFD WALK ADJ
   DW   CMD_ILLEGAL   ; 07H  SET BITS FOR TDC-A CHARGE BASELINE INSPECTOR WINDOW
   DW   CMD_ILLEGAL   ; 08H  SET BITS FOR TDC-B CHARGE BASELINE INSPECTOR WINDOW
   DW   CMD_OPERATE   ; 09H *SET BITS FOR TDC-A STOP (CFD) WALK ADJUSTMENT
   DW   CMD_ILLEGAL   ; 0AH *SET BITS FOR TDC-B STOP (CFD) WALK ADJUSTMENT
   DW   CMD_ILLEGAL   ; 0BH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 0CH  No Operation, undefined command
   DW   CMD_OPERATE   ; 0DH *set max setting for HV A (DAC w/ clamping diode)
   DW   CMD_ILLEGAL   ; 0EH  set max setting for HV B (DAC w/ clamping diode)
   DW   CMD_ILLEGAL   ; 0FH  Mask Box image operation (fast)
   DW   CMD_ILLEGAL   ; 10H  Mask Box image operation (fast)
   DW   CMD_ILLEGAL   ; 11H  Mask Box image operation (fast)
   DW   CMD_ILLEGAL   ; 12H  Mask Box image operation (fast)
   DW   CMD_ILLEGAL   ; 13H  Mask Box image operation (fast)
   DW   CMD_ILLEGAL   ; 14H  Mask Box image operation (fast)
   DW   CMD_OPERATE   ; 15H *TDC-A LOWER CHARGE (Y) THRESHOLD
   DW   CMD_ILLEGAL   ; 16H  SET BITS FOR TDC-B LOWER CHARGE (Y) THRESHOLD
   DW   CMD_OPERATE   ; 17H *TDC-A LOWER TIME (X) THRESHOLD GDGTTX
   DW   CMD_ILLEGAL   ; 18H *TDC-B LOWER TIME (Y) THRESHOLD
   DW   CMD_ILLEGAL   ; 19H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 1AH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 1BH  No Operation, undefined command
   DW   CMD_OPERATE   ; 1Ch  Overrides Endswitches
   DW   CMD_ILLEGAL   ; 1DH  TURNS ON_OFF STIM LAMP
   DW   CMD_OPERATE   ; 1Eh  ; (STIM_ON_OFF_A) TDC-A STIMULUS CONTROL
   DW   CMD_ILLEGAL   ; 1FH  TURNS TDC-B STIMULUS GENERATOR ON_OFF
   DW   CMD_ILLEGAL   ; 20H  SETS STIMULUS GENERATOR A FOR SWEEPING AMPLITUDES
   DW   CMD_ILLEGAL   ; 21H  SETS STIMULUS GENERATOR B FOR SWEEPING AMPLITUDES
   DW   CMD_OPERATE   ; 22H *SET BITS FOR TDC-A UPPER CHARGE (Y) THRESHOLD
   DW   CMD_ILLEGAL   ; 23H  SET BITS FOR TDC-B UPPER CHARGE (Y) THRESHOLD
   DW   CMD_OPERATE   ; 24H  SET BITS FOR TDC-A TIME (X) IMAGE POSITION OFFSET
   DW   CMD_ILLEGAL   ; 25H  SET BITS FOR TDC-B TIME (X) IMAGE POSITION OFFSET
   DW   CMD_OPERATE   ; 26H  SET BITS FOR TDC-A TIME (X) SCALE FACTOR
   DW   CMD_ILLEGAL   ; 27H  SET BITS FOR TDC-B TIME (X) SCALE FACTOR
   DW   CMD_ILLEGAL   ; 28H  set observe mode (observing, special ops, safe,..
   DW   CMD_ILLEGAL   ; 29H  set data format on RS-422{  (for calibration)}
   DW   CMD_ILLEGAL   ; 2AH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 2BH *Enter test mode. (dump pseudo telemetry ...)
   DW   CMD_ILLEGAL   ; 2CH *Check a value (returned as a monitor)
   DW   DCE_LFDUPLOD  ; 2DH  Loads memory with Upload Data block
   DW   DCE_LFDDNLOD  ; 2EH *Dumps memory block: Startaddr, Length, DataCRC32
   DW   CMD_ILLEGAL   ; 2FH   spare
   DW   CMD_ILLEGAL   ; 30H  LOADS IMAGE MASKS FOR SEGMENT A
   DW   CMD_ILLEGAL   ; 31H  LOADS IMAGE MASKS FOR SEGMENT B
   DW   CMD_ILLEGAL   ; 32H  Dumps mask A: Startaddr, Endaddr, DataCRC32
   DW   CMD_ILLEGAL   ; 33H  Dumps mask B: Startaddr, Endaddr, DataCRC32
   DW   CMD_ILLEGAL   ; 34H *SAA COUNT LIMIT FOR SEGMENT A AUTO HV REDUCE
   DW   CMD_ILLEGAL   ; 35H  SAA COUNT LIMIT FOR SEGMENT B AUTO HV REDUCE
   DW   CMD_OPERATE   ; 36H *SAA HV REDUCED VALUE SEGMENT A
   DW   CMD_ILLEGAL   ; 37H  SAA HV REDUCED VALUE SEGMENT B
   DW   CMD_ILLEGAL   ; 38H  SAA HV AUTO SHUTDOWN OVER-RIDE SEGMENT A
   DW   CMD_ILLEGAL   ; 39H  SAA HV AUTO SHUTDOWN OVER-RIDE SEGMENT B
   DW   CMD_OPERATE   ; 3AH *SAA INTEGRATION TIME FOR SEGMENT A AUTO HV REDUCE
   DW   CMD_ILLEGAL   ; 3BH  SAA INTEGRATION TIME FOR SEGMENT B AUTO HV REDUCE
   DW   CMD_ILLEGAL   ; 3CH *SAA SEGMENT AUTO HV REDUCE OFF PERIOD
   DW   CMD_ILLEGAL   ; 3DH   spare
   DW   CMD_ILLEGAL   ; 3EH   spare
   DW   CMD_ILLEGAL   ; 3FH   spare
   DW   CMD_OPERATE   ; 40H *switches HV BIAS supplies on after writing 0 to the DA
   DW   CMD_OPERATE   ; 41H  TURNS ON_OFF ACTUATOR 1
   DW   CMD_OPERATE   ; 42H  TURNS ON_OFF ACTUATOR 2
   DW   CMD_OPERATE   ; 43H  ARMS 28V ACTUATOR PWR SWITCH
   DW   CMD_OPERATE   ; 44H  Turns ON_OFF 28V AUX OSCILLATOR for Motor, Actuator, I
   DW   CMD_OPERATE   ; 45H  Actuator reset sequence
   DW   CMD_OPERATE   ; 46H *LFHVNMA Nom value for HV A
   DW   CMD_ILLEGAL   ; 47H  LFHVNMB Nom value for HV B
   DW   CMD_ILLEGAL   ; 48H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 49H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 4AH *CRP_OVR CRP override
   DW   CMD_OPERATE   ; 4BH *SET BITS FOR MCP-A HV BIAS
   DW   CMD_ILLEGAL   ; 4CH  SET BITS FOR MCP-B HV BIAS
   DW   CMD_ILLEGAL   ; 4DH  No Operation, undefined command
   DW   CMD_OPERATE   ; 4EH *HV_RAMP HV Ramp time constant
   DW   CMD_OPERATE   ; 4FH  switches MCP grid supply on
   DW   CMD_OPERATE   ; 50H *Set HV current limit
   DW   CMD_OPERATE   ; 51H *Enables HV_ON and HVQ_ON (in the DPU = software)
   DW   CMD_ILLEGAL   ; 52H  TURNS ON ION PUMP #1
   DW   CMD_ILLEGAL   ; 53H  TURNS ON ION PUMP #2
   DW   CMD_ILLEGAL   ; 54H  ENABLES ION PUMPS #1& #2
   DW   CMD_ILLEGAL   ; 55H *TDC Begin Y interpolator offset Y_SHIFT_DAC
   DW   CMD_ILLEGAL   ; 56H *TDC End Y interpolator  offset Y_SHIFT_DAE
   DW   CMD_ILLEGAL   ; 57H *TDC Begin Y interpolator scale Y_SCALE_DAC
   DW   CMD_ILLEGAL   ; 58H *TDC End Y interpolator scale Y_SCALE_DAE
   DW   CMD_OPERATE   ; 59H  Sets motor bridge switches (dir.) avoid M1=M2=1
   DW   CMD_OPERATE   ; 5AH  ENABLES MOTOR BRIDGE SW. (may start the motor)
   DW   CMD_OPERATE   ; 5BH  Allows MOTOR_ENA (in the DPU)
   DW   CMD_OPERATE   ; 5CH  Set door current limit
   DW   CMD_ILLEGAL   ; 5DH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 5EH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 5FH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 60H  Mask Box image operation
   DW   CMD_ILLEGAL   ; 61H *TDC Begin X interpolator  offset [#DGBOFFX]
   DW   CMD_ILLEGAL   ; 62H *TDC End X interpolator  offset [#DGEOFFX]
   DW   CMD_ILLEGAL   ; 63H *TDC Begin X interpolator scale [#DGBSCLX]
   DW   CMD_ILLEGAL   ; 64H *TDC End X interpolator scale [#DGESCLX]
   DW   CMD_ILLEGAL   ; 65H  Mask Box image operation
   DW   CMD_OPERATE   ; 66H *Trigger shutdown, no auto restore
   DW   CMD_ILLEGAL   ; 67H *Restore HV saved during shutdown
   DW   CMD_ILLEGAL   ; 68H  Set SAA shutdown values to 80% of HV
   DW   CMD_ILLEGAL   ; 69H  Don't expect anymore commands, no reset
   DW   DCE_LFDGOTO   ; 6AH *Jump to specified address and execute code there
   DW   CMD_ILLEGAL   ; 6BH *CRP enable/disable
   DW   CMD_ILLEGAL   ; 6CH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 6DH  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 6EH *day - Restore HV saved during shutdown
   DW   CMD_ILLEGAL   ; 6FH *night - Trigger shutdown, no auto restore
   DW   DCE_LFDRSTP   ; 70H *power-on reset
   DW   DCE_LFDWDOG   ; 71H *enable/disable watchdog
   DW   CMD_ILLEGAL   ; 72H  No Operation, undefined command
   DW   DCE_LFDJMPCS  ; 73H *jump code
   DW   DCE_LFDDIAGC  ; 74H *clear diags
   DW   DCE_LFDRSTW   ; 75H *watchdog reset
   DW   CMD_ILLEGAL   ; 76H *Enter Idle state, HV off [#DSBITS5]
   DW   CMD_ILLEGAL   ; 77H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 78H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 79H  No Operation, undefined command
   DW   CMD_ILLEGAL   ; 7AH  Toggle reset line to counter actel
   DW   CMD_ILLEGAL   ; 7BH  TDC debug dbb 4-14-00
   DW   CMD_ILLEGAL   ; 7CH  Reserved for J&T
   DW   CMD_ILLEGAL   ; 7DH *Set PROM bit according to parameter
   DW   CMD_ILLEGAL   ; 7EH  dbb 4-1-00
   DW   DCE_LFDHKREQ  ; 7FH *Send full copy of Housekeeping Memory
;-----------------------------------------------------------------------------

;*****************************************************************************
; 'CRC_REGIONS' is an array of 12-byte structures used to implement
; background CRC checking over multiple regions of memory.  The contents of
; each element of the array are as follows:
;    (1)  Starting address in memory (16 bits, big-endian)
;    (2)  Number of bytes to check (16 bits, big-endian)
;    (3)  Memory space (0=XDATA, 1=CODE) (8-bits)
;    (4)  Next region number (8-bits)
;    (5)  CRC for this region (16-bits)
;    (6)  Previous CRC for this region, if non-zero (16-bits)
;    (7)  Diagnostic to send if CRCs miscompare, if MSB=5Ah (16-bits)
; The first entry is region '0', CRC determined by LFDCRC command ('LFMCRC')
; The second entry is region '1', CRC of the PROM. ('LFMROM')
; The third entry is region '2', CRC of the Lower Code Area. ('LFMLWR')
; The fourth entry is region '3', CRC of the Upper Code Area. ('LFMUPR')
; Regions 4-15, allocated here, are for expansion.
; NOTE:  The labels at the beginning and end of this code segment, 
;    'cCRC_REGIONS' and 'end_cCRC_REGIONS' define the maximum number
;    of regions allocated and, hence, allowed ('num_regions').
;    The software will check to ensure that no unauthorized region is
;    requested since this would lead to software 'scribbling' in memory.
; NOTE:  To halt background CRC calculations, merely make a region point to
;    a 'next region' beyond the allowable range (i.e. >= 'num_regions')
; NOTE:  The command 'DCE_LFDCRC' will populate Region 0 with data specific
;    to its assigned task and zero out the 'previous CRC' to prevent
;    diagnostic and/or HST error.  It will NOT change the 'next region'
;    specifier.  That is up to the operator to command such a change.
;    By default, the 'next region' is region 1.
; NOTE:  Upon commencing CRC calculations for any region, the CRC is shown
;    as zero.  The actual CRC value will be written once calculations are
;    complete.  Additionally, if an LFDCRC command is received, the current
;    region will be abandoned and Region 0 will be setup for this command and
;    CRC calculations will begin on Region 0 immediately.
; NOTE:  'cCRC_REGIONS' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'CRC_REGIONS' reflects that XDATA location.  It is the XDATA location
;    ('CRC_REGIONS') which is referenced in the software.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
cCRC_REGIONS:

; Region 0 (used by LFDCRC for its CRC region) ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
cLFMCRC:                 ; CRC mnemonic LFMCRC
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message to send if CRC error
cCRC_REGIONS_00:         ; label used for computing 'sz_regions'

; Region 1 (used for CRC of PROM) ...
   DW   00000h, 01800h   ; starting address, number of bytes
   DB   1, 2             ; 1=CODE space, next region is '2'
cLFMROM:                 ; CRC mnemonic LFMROM
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG001A         ; Diagnostic:  Bad ROM CRC
   
; Region 2 (used for CRC of Lower Code Area) ...
   DW   09800h, 02800h   ; starting address, number of bytes
   DB   1, 3             ; 1=CODE space, next region is '3'
cLFMLWR:                 ; CRC mnemonic LFMLWR
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0018         ; Diagnostic:  Bad LCA CRC
   
; Region 3 (used for CRC of Upper Code Area) ...
   DW   0D800h, 02800h   ; starting address, number of bytes
   DB   1, 1             ; 1=CODE space, next region is '1'
cLFMUPR:                 ; Region 3 CRC is a named quantity
   DW   0, 0             ; calculated CRC, previous CRC
   DW   DIAG0019         ; Diagnostic:  Bad UCA CRC
   
; Region 4 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 5 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 6 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 7 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 8 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 9 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 10 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 11 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 12 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 13 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 14 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message
   
; Region 15 ...
   DW   00000h, 00000h   ; starting address, number of bytes
   DB   0, 1             ; 0=XDATA space, next region is '1'
   DW   0, 0             ; calculated CRC, previous CRC
   DW   0                ; diagnostic message

end_cCRC_REGIONS:

; The software uses 'num_regions' to limit the allowed values for the
; 'next region' parameter. 'sz_regions' is the number of bytes used by
; each entry in the above table ...
sz_regions    equ   (cCRC_REGIONS_00 - cCRC_REGIONS)
num_regions   equ   (end_cCRC_REGIONS - cCRC_REGIONS)/sz_regions
;-----------------------------------------------------------------------------

;*****************************************************************************
; The housekeeping script is composed of 4-byte entries.  The first byte is
; the script opcode and the last byte is the repetition count -- how many
; successive entities of the same type (same opcode) to collect and put
; into housekeeping (also at successive addresses).  The four bytes are:
; (1)  8-bit script opcode:
;        00h -- End of script
;        01h -- Read bytes from CODE space
;        02h -- Read bytes from XDATA space (or memory-mapped I/O)
;        03h -- Read bytes from DATA space
; UNUSED 04h -- Read bytes from digital I/O w/ MUX setting
; UNUSED 05h -- Read BIT from digital I/O w/ MUX setting
;        06h -- Read bytes from Analog I/O
;        07h -- Move housekeeping pointer to specified address
;        08h -- Skip 'N' bytes of housekeeping packet
;        09h -- Clear 'N' bytes of housekeeping packet
;        0Ah -- NOP (leaves an empty line in the script for later use)
;        46h -- Read TDC 'A'
;        82h -- Read TDC 'B'
; (2)  Depending on script opcode, bytes 2 & 3 take on various meanings.
;      Script Opcode -- Bytes 2&3
;        01h -- 16-bit address (MSB first)
;        02h -- 16-bit address (MSB first)
;        03h -- 16-bit address (MSB first, ignored)
; UNUSED 04h -- 16-bit MUX address (MSB first)
; UNUSED 05h -- 8-bit MUX address, 8-bit bit-select mask
;        06h -- 8-bit MUX address, 8-bit MUX delay ctr.
;        07h -- 16-bit address to which to move HKP pointer
;        08h -- N/A
;        09h -- N/A
;        0Ah -- N/A
;        46h -- 8-bit TDC MUX address, 8-bit MUX delay ctr.
;        82h -- 8-bit TDC MUX address, 8-bit MUX delay ctr.
;
; NOTE:  'chkp_script' is the CODE segment label for this table.
;    When this table is copied to XDATA, it is placed elsewhere and label
;    'hkp_script' reflects that XDATA location.  It is the XDATA location
;    ('hkp_script') which is referenced in the software.
;*****************************************************************************

a2d_delay   equ   3   ; MUX settling time (multiples of 0.384 msec @ 8-MHz)

; The housekeeping script for Boot mode is below.  It does not contain all
; operate mode housekeeping items -- only those required for boot.
; NOTE:  In Boot Mode, the housekeeping buffer is 3440h - 383Fh.  When the
;    buffer is transferred to the CS computer, its upper address is masked
;    with 1Fh so as to produce addresses in the range 1440h - 183Fh (same
;    address range as for Operate Mode).
FILL_TO_BOUNDARY   16, 0FFh
chkp_script:
   DB   op_jump,   HIGH(3640h),   LOW(3640h),    0  ; jump to address 3640h
   ;
   DB   op_xdata,  HIGH(mLFDERR), LOW(mLFDERR), 24  ; LFDERR (8 bytes)
                                                    ; LFDERRP (16 bytes)
   DB   op_jump,   HIGH(3664h),   LOW(3664h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(RS17),    LOW(RS17),    28  ; LFDCBUF
   DB   op_xdata,  HIGH(mLFCTIME), LOW(mLFCTIME), 4 ; LFCTIME
   DB   op_jump,   HIGH(36C0h),   LOW(36C0h),    0  ; jump
   ;
   DB   op_a2d,    08h,           a2d_delay,     4  ; LFTDVAA, MUX=08h (1)
                                                    ; LFTACT,  MUX=09h (1)
                                                    ; LFTHVFM, MUX=0Ah (1)
                                                    ; LFTHVPS, MUX=0Bh (1)
   DB   op_a2d,    0Dh,           a2d_delay,     1  ; LFTIP,   MUX=0Dh
   DB   op_a2d,    11h,           a2d_delay,     1  ; LFTDVAB, MUX=11h
   DB   op_a2d,    0Eh,           a2d_delay,     2  ; LFTAMPA, MUX=0Eh (1)
                                                    ; LFTAMPB, MUX=0Fh (1)
   DB   op_a2d,    0Ch,           a2d_delay,     1  ; LFTTDCA, MUX=0Ch
   DB   op_a2d,    10h,           a2d_delay,     1  ; LFTTDCB, MUX=10h
   DB   op_a2d,    12h,           a2d_delay,     2  ; LFTLVPC, MUX=12h (1)
                                                    ; LFTDCE,  MUX=13h (1)
   DB   op_jump,   HIGH(36CDh),   LOW(36CDh),    0  ; jump
   ;
   DB   op_a2d,    15h,           a2d_delay,     1  ; LFVP5DC, MUX=15h
   DB   op_jump,   HIGH(36D8h),   LOW(36D8h),    0  ; jump
   ;
   DB   op_TDC_A,  50h,           a2d_delay,     1  ; LFVP15TA, TDC_A MUX=50h
   DB   op_TDC_B,  50h,           a2d_delay,     1  ; LFVP15TB, TDC_B MUX=50h
   DB   op_TDC_A,  52h,           a2d_delay,     1  ; LFVP5TA,  TDC_A MUX=52h
   DB   op_TDC_B,  52h,           a2d_delay,     1  ; LFVP5TB,  TDC_B MUX=52h
   DB   op_TDC_A,  51h,           a2d_delay,     1  ; LFVM15TA, TDC_A MUX=51h
   DB   op_TDC_B,  51h,           a2d_delay,     1  ; LFVM15TB, TDC_B MUX=51h
   DB   op_TDC_A,  53h,           a2d_delay,     1  ; LFVM5TA,  TDC_A MUX=53h
   DB   op_TDC_B,  53h,           a2d_delay,     1  ; LFVM5TB,  TDC_A MUX=53h
   DB   op_a2d,    16h,           a2d_delay,     2  ; LFVP15D,  MUX=16h (1)
                                                    ; LFVM15D,  MUX=17h (1)
   DB   op_jump,   HIGH(36E4h),   LOW(36E4h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFSBITS2), LOW(mLFSBITS2), 2  ; 'Status bits 2'
   DB   op_jump,   HIGH(36FCh),   LOW(36FCh),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFMROM), LOW(mLFMROM),   2 ; LFMROM
   DB   op_xdata,  HIGH(mLFDSWVER), LOW(mLFDSWVER), 2  ; LFDSWVER
   DB   op_xdata,  HIGH(mLFCPKTL), LOW(mLFCPKTL), 5 ; LFCPKT (4)
                                                    ; LFDLSTC (1)
   DB   op_jump,   HIGH(3706h),   LOW(3706h),     0 ; jump
   ;
   DB   op_TDC_A,  54h,           a2d_delay,     1  ; LFGREFA,  TDC_A MUX=54h
   DB   op_TDC_B,  54h,           a2d_delay,     1  ; LFGREFB,  TDC_B MUX=54h
   DB   op_xdata,  HIGH(tLFDDIAGS+0), LOW(tLFDDIAGS+0), 1  ; LFDDIAG0
   DB   op_xdata,  HIGH(tLFDDIAGS+2), LOW(tLFDDIAGS+2), 1  ; LFDDIAG1
   DB   op_jump,   HIGH(370Ch),   LOW(370Ch),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDCMDX), LOW(mLFDCMDX), 2 ; LFDCMDX
   DB   op_jump,   HIGH(3710h),   LOW(3710h),     0 ; jump
   ;
   DB   op_a2d,    43h,           a2d_delay,     1  ; LFVPMON,  MUX=43h
   DB   op_xdata,  HIGH(tLFDDIAGS+4), LOW(tLFDDIAGS+4), 1  ; LFDDIAG2
   DB   op_jump,   HIGH(3718h), LOW(3718h),      0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFDCMDR), LOW(mLFDCMDR), 2 ; LFDCMDR
   DB   op_xdata,  HIGH(mLFMCRC), LOW(mLFMCRC),   2 ; LFDCRC
   DB   op_jump,   HIGH(3730h),   LOW(3730h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(mLFDPERF), LOW(mLFDPERF), 2 ; LFDPERF
   DB   op_jump,   HIGH(3736h),   LOW(3736h),     0 ; jump
   ;
   DB   op_xdata,  HIGH(mLFDMEXTR), LOW(mLFDMEXTR), 26  ; LFDMEXTR (1)
                                                        ; LFDMDATA (1)
                                                        ; LFDMONS (8)
                                                        ; LFDMADD (16)
   DB   op_jump,   HIGH(3776h),   LOW(3776h),    0  ; jump
   ;
   DB   op_xdata,  HIGH(tLFDDIAGS+6), LOW(tLFDDIAGS+6), 1 ; LFDDIAG3
   DB   op_xdata,  HIGH(tLFDDIAGS+8), LOW(tLFDDIAGS+8), 1 ; LFDDIAG4
   DB   op_jump,   HIGH(377Ch),   LOW(377Ch),    0  ; jump
   ;
   DB   op_xdata,  HIGH(mLFMLWR), LOW(mLFMLWR),  2  ; LFDLWR
   DB   op_xdata,  HIGH(mLFMUPR), LOW(mLFMUPR),  2  ; LFDUPR
   DB   op_xdata,  HIGH(mLFDDIAGS), LOW(mLFDDIAGS), 64  ; LFDDIAGS
   DB   op_a2d,    80h,           a2d_delay,     2  ; MUX=80h, DCE-A +5V
                                                    ; MUX=81h, DCE-B +5V
   ;
   ; The rest is blank -- leave it so.
   ;
   DB   op_end,    0,0,0 ; end of script

   ; Save room for future growth of the script ...
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
   DW   0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
;-----------------------------------------------------------------------------

end_patchable_CSEG:         ; ending label (in CODE segment) of area to be
                            ; copied from CODE to XDATA upon initialization

; The above patchable constants will be copied to XDATA beginning at address
; 'PC04' (see common.inc).

;*****************************************************************************
; 'patch_table' is a list of all blocks of patchable constants which are to be
; copied from CODE to XDATA.  Each entry is composed of 3 words:
; (1)  CODE segment block starting address
; (2)  XDATA destination address
; (3)  Number of bytes to copy
; If the number of bytes is zero, that indicates the end of 'patch_table'.
;*****************************************************************************
FILL_TO_BOUNDARY   16, 0FFh
patch_table:
   DW   patchable_CSEG, PC04, end_patchable_CSEG-patchable_CSEG
   DW   0, 0, 0   ; end of patch_table
;-----------------------------------------------------------------------------

;*****************************************************************************
; Those patchable constants which are referred to BY NAME in the software
; must have their XDATA address specified as an equate.  Since they reside
; in the CODE segment beginning at address 'patchable_CSEG' and in XDATA
; beginning at address 'PC04', we merely add to the CODE segment address the
; difference between these two offsets to find the XDATA address.
;*****************************************************************************
mLFDSWVER      equ   cLFDSWVER     + (PC04-patchable_CSEG)
mLFMCRC        equ   cLFMCRC       + (PC04-patchable_CSEG)
mLFMLWR        equ   cLFMLWR       + (PC04-patchable_CSEG)
mLFMUPR        equ   cLFMUPR       + (PC04-patchable_CSEG)
mLFMROM        equ   cLFMROM       + (PC04-patchable_CSEG)
HSTERR_TABLE   equ   cHSTERR_TABLE + (PC04-patchable_CSEG)
COS_BOOT_TBL   equ   cCOS_BOOT_TBL + (PC04-patchable_CSEG)
CRC_REGIONS    equ   cCRC_REGIONS  + (PC04-patchable_CSEG)
hkp_script     equ   chkp_script   + (PC04-patchable_CSEG)
;-----------------------------------------------------------------------------

;*****************************************************************************
; In order to prevent accidentally overlapping XDATA memory usage, we will
; block out an area of XDATA of the same size as the patchable constants to
; be copied (and at the same addresses, of course).  Additionally, space for
; the upload buffer, download buffer, command buffer, and housekeeping buffer
; is reserved.  This approach allows the linker to warn us if another XDATA
; allocation overlaps any of these areas.
;*****************************************************************************
   XSEG  at  RS01              ; reserve 1024 bytes for upload buffer
xRS01:   DS  1024

   XSEG  at  RS17              ; reserve 28 bytes for command packet
xRS17:   DS  28

   XSEG  at  TS01              ; reserve 1024 bytes for download buffer
xTS01:   DS  1024

   XSEG  at  TS17              ; reserve 1024 bytes for housekeeping buffer
xTS17:   DS  1024

   XSEG  at  PC04              ; reserve the patchable constants space
xPATCH:  DS  end_patchable_CSEG-patchable_CSEG
;-----------------------------------------------------------------------------

;*****************************************************************************
; Working copies of items which will go into the housekeeping packet are
; allocated here.  Subroutine 'BUILD_HKP' constructs the housekeeping
; packet from information herein and elsewhere.  Where possible, blocks of
; items here are layed out in the same order (within the block) as the
; expected order in housekeeping, in order to simplify and speed-up the
; copy-to-housekeeping which is performed in 'BUILD_HKP'.
;*****************************************************************************
   XSEG   at   PC00

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Memory Monitor parameters (KEEP IN THIS ORDER) ...
mLFDMEXTR:   DS    1        ; external/internal select bits
mLFDMDATA:   DS    1        ; data/code select bits
mLFDMONS:    DS    8        ; data values
mLFDMADD:    DS   16        ; addresses
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mLFDERR:     DS    8        ; 8 HST error locations
mLFDERRP:    DS   16        ; 8 HST error parameters
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; KEEP IN THIS ORDER ...
mLFCPKTL:    DS    4        ; packet counter (long word)
mLFDLSTC:    DS    1        ; last DCE Op-code executed
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; Various others (need not be kept in order) ...

; Diagnostics and HST errors ...
tLFDDIAGS    equ   $        ; assembler need a little help with its math,
                            ; so create this 'equate' at the same address as
                            ; 'mLFDDIAGS'
mLFDDIAGS:   DS   64        ; Push-down stack of last 32 diagnostic msgs.
mDIAG_NUM:   DS    1        ; counter of total number of diagnostics

; Various counters ...
mLFDCMDR:    DS    2        ; commands received counter
mLFDCMDX:    DS    2        ; commands executed counter
mLFDPERF:    DS    2        ; DCE Performance monitor.  Exec. loop counter.
mLFCTIME:    DS    4        ; seconds counter
mLFMXFER:    DS    2        ; upload/download packet CRC

; 6 status words (first 4 are 16-bits each, last 2 are 8-bits each) ...
mLFSBITS0:   DS    2
mLFSBITS1:   DS    2
mLFSBITS2:   DS    2
mLFSBITS3:   DS    2
mLFSBITS4:   DS    1
mLFSBITS5:   DS    1

             DS    PC04-$   ; Block out the rest of the space up to where
                            ; the patchable constants begin (address 'PC00').
;-----------------------------------------------------------------------------

END                         ; patchcst.a51

